@@ -929,7 +929,7 @@ mod table_keys_order {
                 if let Some(schema_path) = $schema_path {
                     // Load schemas
                     schema_store
-                        .load_schemas(
+                        .load_config_schemas(
                             &[tombi_config::Schema::Root(tombi_config::RootSchema {
                                 toml_version: None,
                                 path: schema_path.to_string_lossy().to_string(),
