@@ -43,12 +43,6 @@ impl Token {
 
 impl std::fmt::Debug for Token {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(
-            f,
-            "{:?} @{:?} @{:?}",
-            self.kind,
-            self.span,
-            tombi_text::Range::new_1_based(self.range)
-        )
+        write!(f, "{:?} @{:?} @{:?}", self.kind, self.span, self.range)
     }
 }
