@@ -59,7 +59,7 @@ macro_rules! test_lint {
             if let Some(schema_path) = $schema_path {
                 // Load schemas
                 schema_store
-                    .load_schemas(
+                    .load_config_schemas(
                         &[tombi_config::Schema::Root(tombi_config::RootSchema {
                             toml_version: None,
                             path: schema_path.to_string_lossy().to_string(),
@@ -80,12 +80,14 @@ macro_rules! test_lint {
                 &schema_store,
             );
 
-            let result = linter.lint($source).await;
-
-            match result {
+            match linter.lint($source).await {
                 Ok(_) => {}
                 Err(errors) => {
-                    panic!("Expected success but got errors: {:?}", errors);
+                    pretty_assertions::assert_eq!(
+                        Vec::<tombi_diagnostic::Diagnostic>::new(),
+                        errors,
+                        "Expected success but got errors."
+                    );
                 }
             }
         }
@@ -135,7 +137,7 @@ macro_rules! test_lint {
             if let Some(schema_path) = $schema_path {
                 // Load schemas
                 schema_store
-                    .load_schemas(
+                    .load_config_schemas(
                         &[tombi_config::Schema::Root(tombi_config::RootSchema {
                             toml_version: None,
                             path: schema_path.to_string_lossy().to_string(),
@@ -179,7 +181,7 @@ macro_rules! test_lint {
 mod tests {
     use super::*;
 
-    mod cargo {
+    mod cargo_schema {
         use super::*;
         use tombi_test_lib::cargo_schema_path;
 
@@ -208,7 +210,7 @@ mod tests {
                 accessors: tombi_schema_store::SchemaAccessors::new(vec![
                     tombi_schema_store::SchemaAccessor::Key("workspace".to_string()),
                 ]),
-                schema_url: tombi_schema_store::SchemaUrl::from_file_path(cargo_schema_path()).unwrap(),
+                schema_uri: tombi_schema_store::SchemaUri::from_file_path(cargo_schema_path()).unwrap(),
                 key: "aaa".to_string(),
             }]);
         }
@@ -281,6 +283,23 @@ mod tests {
         }
     }
 
+    mod untagged_union_schema {
+        use super::*;
+        use tombi_test_lib::untagged_union_schema_path;
+
+        test_lint! {
+            #[test]
+            fn test_untagged_union_schema(
+                r#"
+                #:schema schemas/untagged-union.schema.json
+
+                favorite_color = "blue"
+                "#,
+                untagged_union_schema_path(),
+            ) -> Ok(_);
+        }
+    }
+
     mod other_schema {
         test_lint! {
             // Ref: https://github.com/tombi-toml/tombi/issues/517
@@ -303,7 +322,7 @@ mod tests {
     }
 
     mod non_schema {
-        use tombi_schema_store::SchemaUrl;
+        use tombi_schema_store::SchemaUri;
 
         use super::*;
 
@@ -343,7 +362,7 @@ mod tests {
 
         test_lint! {
             #[test]
-            fn test_schema_url(
+            fn test_schema_uri(
                 r#"
                 #:schema https://json.schemastore.org/tombi.json
                 "#,
@@ -367,7 +386,7 @@ mod tests {
                 "#,
             ) -> Err([
                 tombi_schema_store::Error::SchemaFetchFailed{
-                    schema_url: SchemaUrl::parse("https://does-not-exist.co.jp").unwrap(),
+                    schema_uri: SchemaUri::parse("https://does-not-exist.co.jp").unwrap(),
                     reason: "error sending request for url (https://does-not-exist.co.jp/)".to_string(),
                 }
             ]);
