@@ -13,26 +13,39 @@ pub async fn handle_get_toml_version(
     tracing::trace!(?params);
 
     let TextDocumentIdentifier { uri } = params;
+    let text_document_uri = uri.into();
 
     let ConfigSchemaStore {
         config,
         schema_store,
+        ..
     } = backend
         .config_manager
-        .config_schema_store_for_url(&uri)
+        .config_schema_store_for_uri(&text_document_uri)
         .await;
 
-    let source_schema = match backend.get_incomplete_ast(&uri).await {
+    let root_ast = backend.get_incomplete_ast(&text_document_uri).await;
+
+    let source_schema = match &root_ast {
         Some(root) => schema_store
-            .resolve_source_schema_from_ast(&root, Some(Either::Left(&uri)))
+            .resolve_source_schema_from_ast(root, Some(Either::Left(&text_document_uri)))
             .await
             .ok()
             .flatten(),
         None => None,
     };
 
+    let document_tombi_comment_directive = match root_ast.as_ref() {
+        Some(root) => tombi_comment_directive::get_document_tombi_comment_directive(root).await,
+        None => None,
+    };
+
     let (toml_version, source) = backend
-        .source_toml_version(source_schema.as_ref(), &config)
+        .source_toml_version(
+            document_tombi_comment_directive,
+            source_schema.as_ref(),
+            &config,
+        )
         .await;
 
     Ok(GetTomlVersionResponse {
@@ -51,7 +64,28 @@ pub struct GetTomlVersionResponse {
 #[derive(Debug, serde::Serialize)]
 #[serde(rename_all = "lowercase")]
 pub enum TomlVersionSource {
-    Config,
+    /// Comment directive
+    ///
+    /// ```toml
+    /// #:tombi toml-version = "v1.0.0"
+    /// ```
+    Comment,
+
+    /// Schema directive
+    ///
+    /// ```toml
+    /// #:schema "https://example.com/schema.json"
+    /// ```
     Schema,
+
+    /// Config file
+    ///
+    /// ```toml
+    /// [tombi]
+    /// toml-version = "v1.0.0"
+    /// ```
+    Config,
+
+    /// Default
     Default,
 }
