@@ -11,7 +11,7 @@ use crate::hover::{
     any_of::get_any_of_hover_content,
     constraints::{build_enumerate_values, ValueConstraints},
     one_of::get_one_of_hover_content,
-    GetHoverContent, HoverContent,
+    GetHoverContent, HoverValueContent,
 };
 
 impl GetHoverContent for tombi_document_tree::Table {
@@ -22,7 +22,7 @@ impl GetHoverContent for tombi_document_tree::Table {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
         tracing::trace!("self = {:?}", self);
         tracing::trace!("keys = {:?}", keys);
         tracing::trace!("accessors = {:?}", accessors);
@@ -31,7 +31,7 @@ impl GetHoverContent for tombi_document_tree::Table {
         async move {
             if let Some(Ok(DocumentSchema {
                 value_schema,
-                schema_url,
+                schema_uri,
                 definitions,
                 ..
             })) = schema_context
@@ -40,7 +40,7 @@ impl GetHoverContent for tombi_document_tree::Table {
             {
                 let current_schema = value_schema.map(|value_schema| CurrentSchema {
                     value_schema: Cow::Owned(value_schema),
-                    schema_url: Cow::Owned(schema_url),
+                    schema_uri: Cow::Owned(schema_uri),
                     definitions: Cow::Owned(definitions),
                 });
 
@@ -60,8 +60,8 @@ impl GetHoverContent for tombi_document_tree::Table {
                     ValueSchema::Table(table_schema) => {
                         if let Some(key) = keys.first() {
                             if let Some(value) = self.get(key) {
-                                let key_str = key.to_raw_text(schema_context.toml_version);
-                                let accessor = Accessor::Key(key_str.clone());
+                                let key_string = key.to_raw_text(schema_context.toml_version);
+                                let accessor = Accessor::Key(key_string.clone());
                                 let key_patterns = match table_schema.pattern_properties.as_ref() {
                                     Some(pattern_properties) => Some(
                                         pattern_properties
@@ -86,12 +86,12 @@ impl GetHoverContent for tombi_document_tree::Table {
                                     let required = table_schema
                                         .required
                                         .as_ref()
-                                        .map(|r| r.contains(&key_str))
+                                        .map(|r| r.contains(&key_string))
                                         .unwrap_or(false);
 
                                     if let Ok(Some(current_schema)) = property_schema
                                         .resolve(
-                                            current_schema.schema_url.clone(),
+                                            current_schema.schema_uri.clone(),
                                             current_schema.definitions.clone(),
                                             schema_context.store,
                                         )
@@ -195,10 +195,10 @@ impl GetHoverContent for tombi_document_tree::Table {
                                     ) in pattern_properties.write().await.iter_mut()
                                     {
                                         if let Ok(pattern) = regex::Regex::new(property_key) {
-                                            if pattern.is_match(&key_str) {
+                                            if pattern.is_match(&key_string) {
                                                 if let Ok(Some(current_schema)) = property_schema
                                                     .resolve(
-                                                        current_schema.schema_url.clone(),
+                                                        current_schema.schema_uri.clone(),
                                                         current_schema.definitions.clone(),
                                                         schema_context.store,
                                                     )
@@ -319,7 +319,7 @@ impl GetHoverContent for tombi_document_tree::Table {
                                         referable_additional_property_schema.write().await;
                                     if let Ok(Some(current_schema)) = referable_schema
                                         .resolve(
-                                            current_schema.schema_url.clone(),
+                                            current_schema.schema_uri.clone(),
                                             current_schema.definitions.clone(),
                                             schema_context.store,
                                         )
@@ -418,7 +418,7 @@ impl GetHoverContent for tombi_document_tree::Table {
                             keys,
                             accessors,
                             one_of_schema,
-                            &current_schema.schema_url,
+                            &current_schema.schema_uri,
                             &current_schema.definitions,
                             schema_context,
                         )
@@ -431,7 +431,7 @@ impl GetHoverContent for tombi_document_tree::Table {
                             keys,
                             accessors,
                             any_of_schema,
-                            &current_schema.schema_url,
+                            &current_schema.schema_uri,
                             &current_schema.definitions,
                             schema_context,
                         )
@@ -444,7 +444,7 @@ impl GetHoverContent for tombi_document_tree::Table {
                             keys,
                             accessors,
                             all_of_schema,
-                            &current_schema.schema_url,
+                            &current_schema.schema_uri,
                             &current_schema.definitions,
                             schema_context,
                         )
@@ -472,13 +472,13 @@ impl GetHoverContent for tombi_document_tree::Table {
                             .await;
                     }
                 }
-                Some(HoverContent {
+                Some(HoverValueContent {
                     title: None,
                     description: None,
                     accessors: Accessors::new(accessors.to_vec()),
                     value_type: ValueType::Table,
                     constraints: None,
-                    schema_url: None,
+                    schema_uri: None,
                     range: Some(self.range()),
                 })
             }
@@ -495,9 +495,9 @@ impl GetHoverContent for TableSchema {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
         async move {
-            Some(HoverContent {
+            Some(HoverValueContent {
                 title: self.title.clone(),
                 description: self.description.clone(),
                 accessors: Accessors::new(accessors.to_vec()),
@@ -524,7 +524,7 @@ impl GetHoverContent for TableSchema {
                     keys_order: self.keys_order,
                     ..Default::default()
                 }),
-                schema_url: current_schema.map(|schema| schema.schema_url.as_ref().clone()),
+                schema_uri: current_schema.map(|schema| schema.schema_uri.as_ref().clone()),
                 range: None,
             })
         }
