@@ -547,7 +547,7 @@ mod completion_edit {
                 let backend = service.inner();
 
                 if let Some(schema_file_path) = $schema_file_path.as_ref() {
-                    let schema_url = tombi_schema_store::SchemaUrl::from_file_path(schema_file_path)
+                    let schema_uri = tombi_schema_store::SchemaUri::from_file_path(schema_file_path)
                         .expect(
                             format!(
                                 "failed to convert schema path to URL: {}",
@@ -557,11 +557,11 @@ mod completion_edit {
                         );
                     backend
                         .config_manager
-                        .load_schemas(
+                        .load_config_schemas(
                             &[
                                 tombi_config::Schema::Root(tombi_config::RootSchema {
                                     toml_version: None,
-                                    path: schema_url.to_string(),
+                                    path: schema_uri.to_string(),
                                     include: vec!["*.toml".to_string()],
                                 }),
                             ],
