@@ -44,7 +44,7 @@ mod completion_labels {
             async fn tombi_comment_schema_directive(
                 "#:█",
                 Schema(tombi_schema_path()),
-            ) -> Ok(["schema"]);
+            ) -> Ok(["schema", "tombi"]);
         }
 
         test_completion_labels! {
@@ -52,7 +52,7 @@ mod completion_labels {
             async fn tombi_comment_space_schema_directive(
                 "# :█",
                 Schema(tombi_schema_path()),
-            ) -> Ok(["schema"]);
+            ) -> Ok(["schema", "tombi"]);
         }
 
         test_completion_labels! {
@@ -74,7 +74,7 @@ mod completion_labels {
                 #:█
                 "#,
                 Schema(tombi_schema_path()),
-            ) -> Ok([]);
+            ) -> Ok(["tombi"]);
         }
 
         test_completion_labels! {
@@ -968,6 +968,23 @@ mod completion_labels {
         }
     }
 
+    mod untagged_union {
+        use tombi_test_lib::untagged_union_schema_path;
+
+        use super::*;
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn untagged_union(
+                "█",
+                Schema(untagged_union_schema_path()),
+            ) -> Ok([
+                "favorite_color",
+                "number_of_pets",
+            ]);
+        }
+    }
+
     mod without_schema {
         use super::*;
 
@@ -1282,7 +1299,7 @@ mod completion_labels {
                 let backend = service.inner();
 
                 if let Some(schema_file_path) = $schema_file_path.as_ref() {
-                    let schema_url = tombi_schema_store::SchemaUrl::from_file_path(schema_file_path)
+                    let schema_uri = tombi_schema_store::SchemaUri::from_file_path(schema_file_path)
                         .expect(
                             format!(
                                 "failed to convert schema path to URL: {}",
@@ -1293,12 +1310,12 @@ mod completion_labels {
 
                     backend
                         .config_manager
-                        .load_schemas(
+                        .load_config_schemas(
                             &[
                                 tombi_config::Schema::Root(
                                     tombi_config::RootSchema {
                                         toml_version: None,
-                                        path: schema_url.to_string(),
+                                        path: schema_uri.to_string(),
                                         include: vec!["*.toml".to_string()],
                                     }
                                 )
@@ -1533,7 +1550,7 @@ mod completion_labels {
                 let backend = service.inner();
 
                 if let Some(schema_file_path) = $schema_file_path.as_ref() {
-                    let schema_url = tombi_schema_store::SchemaUrl::from_file_path(schema_file_path)
+                    let schema_uri = tombi_schema_store::SchemaUri::from_file_path(schema_file_path)
                         .expect(
                             format!(
                                 "failed to convert schema path to URL: {}",
@@ -1544,12 +1561,12 @@ mod completion_labels {
 
                     backend
                         .config_manager
-                        .load_schemas(
+                        .load_config_schemas(
                             &[
                                 tombi_config::Schema::Root(
                                     tombi_config::RootSchema {
                                         toml_version: None,
-                                        path: schema_url.to_string(),
+                                        path: schema_uri.to_string(),
                                         include: vec!["*.toml".to_string()],
                                     }
                                 )
@@ -1559,7 +1576,7 @@ mod completion_labels {
                         .await;
                 }
 
-                let subschema_url = tombi_schema_store::SchemaUrl::from_file_path($subschema_file_path)
+                let subschema_uri = tombi_schema_store::SchemaUri::from_file_path($subschema_file_path)
                     .expect(
                         format!(
                             "failed to convert subschema path to URL: {}",
@@ -1570,11 +1587,11 @@ mod completion_labels {
 
                 backend
                     .config_manager
-                    .load_schemas(
+                    .load_config_schemas(
                         &[
                             tombi_config::Schema::Sub(
                                 tombi_config::SubSchema {
-                                    path: subschema_url.to_string(),
+                                    path: subschema_uri.to_string(),
                                     include: vec!["*.toml".to_string()],
                                     root: $root.to_string(),
                                 }
