@@ -128,6 +128,19 @@ mod hover_keys_value {
                 "Value": "String"
             });
         );
+
+        test_hover_keys_value!(
+            #[tokio::test]
+            async fn tombi_comment_directive_toml_version(
+                r#"
+                #:tombi toml-version█ = "v1.0.0"
+                "#,
+                tombi_schema_path(),
+            ) -> Ok({
+                "Keys": "toml-version",
+                "Value": "String?"
+            });
+        );
     }
 
     mod cargo_schema {
@@ -456,7 +469,7 @@ mod hover_keys_value {
                 let backend = service.inner();
 
                 if let Some(schema_file_path) = &$schema_file_path {
-                    let schema_file_url = tombi_schema_store::SchemaUrl::from_file_path(schema_file_path).expect(
+                    let schema_file_url = tombi_schema_store::SchemaUri::from_file_path(schema_file_path).expect(
                         format!(
                             "failed to convert schema path to URL: {}",
                             schema_file_path.display()
@@ -465,7 +478,7 @@ mod hover_keys_value {
                     );
                     backend
                         .config_manager
-                        .load_schemas(
+                        .load_config_schemas(
                             &[
                                 tombi_config::Schema::Root(
                                     tombi_config::RootSchema {
@@ -518,7 +531,7 @@ mod hover_keys_value {
                 )
                 .await;
 
-                let Ok(Some(hover_content)) = tombi_lsp::handler::handle_hover(
+                let Ok(Some(tombi_lsp::HoverContent::Value(hover_content))) = tombi_lsp::handler::handle_hover(
                     &backend,
                     tower_lsp::lsp_types::HoverParams {
                         text_document_position_params: tower_lsp::lsp_types::TextDocumentPositionParams {
@@ -539,9 +552,9 @@ mod hover_keys_value {
                 tracing::debug!("hover_content: {:#?}", hover_content);
 
                 if $schema_file_path.is_some() {
-                    assert!(hover_content.schema_url.is_some(), "The hover target is not defined in the schema.");
+                    assert!(hover_content.schema_uri.is_some(), "The hover target is not defined in the schema.");
                 } else {
-                    assert!(hover_content.schema_url.is_none(), "The hover target is defined in the schema.");
+                    assert!(hover_content.schema_uri.is_none(), "The hover target is defined in the schema.");
                 }
 
                 pretty_assertions::assert_eq!(hover_content.accessors.to_string(), $keys, "Keys are not equal");
