@@ -1,24 +1,24 @@
 use ahash::AHashMap;
 
-use super::{DocumentSchema, SchemaUrl};
+use super::{DocumentSchema, SchemaUri};
 use crate::{SchemaAccessor, SchemaAccessors};
 
-pub type SubSchemaUrlMap = AHashMap<Vec<SchemaAccessor>, SchemaUrl>;
+pub type SubSchemaUriMap = AHashMap<Vec<SchemaAccessor>, SchemaUri>;
 
 #[derive(Clone)]
 pub struct SourceSchema {
     pub root_schema: Option<DocumentSchema>,
-    pub sub_schema_url_map: SubSchemaUrlMap,
+    pub sub_schema_uri_map: SubSchemaUriMap,
 }
 
 impl std::fmt::Debug for SourceSchema {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let root_schema_url = self
+        let root_schema_uri = self
             .root_schema
             .as_ref()
-            .map(|schema| schema.schema_url.to_string());
-        let sub_schema_url_map = self
-            .sub_schema_url_map
+            .map(|schema| schema.schema_uri.to_string());
+        let sub_schema_uri_map = self
+            .sub_schema_uri_map
             .iter()
             .map(|(accessors, url)| {
                 format!("[{:?}]: {}", SchemaAccessors::new(accessors.clone()), url)
@@ -27,7 +27,7 @@ impl std::fmt::Debug for SourceSchema {
             .join(", ");
         write!(
             f,
-            "SourceSchema {{ root_schema: {root_schema_url:?}, sub_schema_url_map: {sub_schema_url_map:?} }}"
+            "SourceSchema {{ root_schema: {root_schema_uri:?}, sub_schema_uri_map: {sub_schema_uri_map:?} }}"
         )
     }
 }
