@@ -1,14 +1,15 @@
-use std::{borrow::Cow, sync::Arc};
+use std::{borrow::Cow, str::FromStr, sync::Arc};
 
 use futures::future::join_all;
 use indexmap::IndexSet;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_json::StringNode;
+use tombi_x_keyword::StringFormat;
 
 use super::{
     referable_schema::CurrentSchema, AllOfSchema, AnyOfSchema, ArraySchema, BooleanSchema,
     FindSchemaCandidates, FloatSchema, IntegerSchema, LocalDateSchema, LocalDateTimeSchema,
-    LocalTimeSchema, OffsetDateTimeSchema, OneOfSchema, SchemaUrl, StringSchema, TableSchema,
+    LocalTimeSchema, OffsetDateTimeSchema, OneOfSchema, SchemaUri, StringSchema, TableSchema,
 };
 use crate::{Accessor, Referable, SchemaDefinitions, SchemaStore};
 
@@ -31,10 +32,13 @@ pub enum ValueSchema {
 }
 
 impl ValueSchema {
-    pub fn new(object: &tombi_json::ObjectNode) -> Option<Self> {
+    pub fn new(
+        object: &tombi_json::ObjectNode,
+        string_formats: Option<&[StringFormat]>,
+    ) -> Option<Self> {
         match object.get("type") {
             Some(tombi_json::ValueNode::String(type_str)) => {
-                return Self::new_single(type_str.value.as_str(), object)
+                return Self::new_single(type_str.value.as_str(), object, string_formats)
             }
             Some(tombi_json::ValueNode::Array(types)) => {
                 let schemas = types
@@ -42,13 +46,13 @@ impl ValueSchema {
                     .iter()
                     .filter_map(|type_value| {
                         if let tombi_json::ValueNode::String(type_str) = type_value {
-                            Self::new_single(type_str.value.as_str(), object)
+                            Self::new_single(type_str.value.as_str(), object, string_formats)
                         } else {
                             None
                         }
                     })
                     .map(|value_schema| Referable::Resolved {
-                        schema_url: None,
+                        schema_uri: None,
                         value: value_schema,
                     })
                     .collect();
@@ -62,30 +66,35 @@ impl ValueSchema {
         }
 
         if object.get("oneOf").is_some() {
-            return Some(ValueSchema::OneOf(OneOfSchema::new(object)));
+            return Some(ValueSchema::OneOf(OneOfSchema::new(object, string_formats)));
         }
         if object.get("anyOf").is_some() {
-            return Some(ValueSchema::AnyOf(AnyOfSchema::new(object)));
+            return Some(ValueSchema::AnyOf(AnyOfSchema::new(object, string_formats)));
         }
         if object.get("allOf").is_some() {
-            return Some(ValueSchema::AllOf(AllOfSchema::new(object)));
+            return Some(ValueSchema::AllOf(AllOfSchema::new(object, string_formats)));
         }
         if let Some(tombi_json::ValueNode::Array(enum_values)) = object.get("enum") {
-            return Self::new_enum_value(object, enum_values);
+            return Self::new_enum_value(object, enum_values, string_formats);
         }
 
         None
     }
 
-    fn new_single(type_str: &str, object: &tombi_json::ObjectNode) -> Option<Self> {
+    fn new_single(
+        type_str: &str,
+        object: &tombi_json::ObjectNode,
+        string_formats: Option<&[StringFormat]>,
+    ) -> Option<Self> {
         match type_str {
             "null" => Some(ValueSchema::Null),
             "boolean" => Some(ValueSchema::Boolean(BooleanSchema::new(object))),
             "integer" => Some(ValueSchema::Integer(IntegerSchema::new(object))),
             "number" => Some(ValueSchema::Float(FloatSchema::new(object))),
             "string" => {
-                if let Some(tombi_json::ValueNode::String(StringNode {
-                    value: format_str, ..
+                let string_format = if let Some(tombi_json::ValueNode::String(StringNode {
+                    value: format_str,
+                    ..
                 })) = object.get("format")
                 {
                     // See: https://json-schema.org/understanding-json-schema/reference/type#built-in-formats
@@ -112,13 +121,28 @@ impl ValueSchema {
                             //       partial-time: used [schemars](https://github.com/GREsau/schemars).
                             return Some(ValueSchema::LocalTime(LocalTimeSchema::new(object)));
                         }
-                        _ => {}
+                        _ => string_formats.and_then(|string_formats| {
+                            if let Some(string_format) =
+                                StringFormat::from_str(format_str.as_str()).ok()
+                            {
+                                if string_formats.contains(&string_format) {
+                                    return Some(string_format);
+                                }
+                            }
+                            None
+                        }),
                     }
-                }
-                Some(ValueSchema::String(StringSchema::new(object)))
+                } else {
+                    None
+                };
+
+                Some(ValueSchema::String(StringSchema::new(
+                    object,
+                    string_format,
+                )))
             }
-            "array" => Some(ValueSchema::Array(ArraySchema::new(object))),
-            "object" => Some(ValueSchema::Table(TableSchema::new(object))),
+            "array" => Some(ValueSchema::Array(ArraySchema::new(object, string_formats))),
+            "object" => Some(ValueSchema::Table(TableSchema::new(object, string_formats))),
             _ => None,
         }
     }
@@ -126,6 +150,7 @@ impl ValueSchema {
     fn new_enum_value(
         object: &tombi_json::ObjectNode,
         enum_values: &tombi_json::ArrayNode,
+        string_formats: Option<&[StringFormat]>,
     ) -> Option<Self> {
         let mut enum_types = IndexSet::new();
         for enum_value in &enum_values.items {
@@ -152,14 +177,14 @@ impl ValueSchema {
             0 => None,
             1 => {
                 let value_type = enum_types.into_iter().next().unwrap();
-                Self::new_single(value_type, object)
+                Self::new_single(value_type, object, string_formats)
             }
             _ => {
                 let mut schemas = Vec::with_capacity(enum_types.len());
                 for value_type in enum_types {
-                    if let Some(schema) = Self::new_single(value_type, object) {
+                    if let Some(schema) = Self::new_single(value_type, object, string_formats) {
                         schemas.push(Referable::Resolved {
-                            schema_url: None,
+                            schema_uri: None,
                             value: schema,
                         });
                     }
@@ -379,7 +404,7 @@ impl ValueSchema {
     pub fn match_flattened_schemas<'a: 'b, 'b, T: Fn(&ValueSchema) -> bool + Sync + Send>(
         &'a self,
         condition: &'a T,
-        schema_url: &'a SchemaUrl,
+        schema_uri: &'a SchemaUri,
         definitions: &'a SchemaDefinitions,
         schema_store: &'a SchemaStore,
     ) -> BoxFuture<'b, Vec<ValueSchema>> {
@@ -392,7 +417,7 @@ impl ValueSchema {
                     for referable_schema in schemas.write().await.iter_mut() {
                         if let Ok(Some(current_schema)) = referable_schema
                             .resolve(
-                                Cow::Borrowed(schema_url),
+                                Cow::Borrowed(schema_uri),
                                 Cow::Borrowed(definitions),
                                 schema_store,
                             )
@@ -403,7 +428,7 @@ impl ValueSchema {
                                     .value_schema
                                     .match_flattened_schemas(
                                         condition,
-                                        &current_schema.schema_url,
+                                        &current_schema.schema_uri,
                                         &current_schema.definitions,
                                         schema_store,
                                     )
@@ -427,7 +452,7 @@ impl ValueSchema {
     pub fn is_match<'a, 'b, T: Fn(&ValueSchema) -> bool + Sync + Send>(
         &'a self,
         condition: &'a T,
-        schema_url: &'a SchemaUrl,
+        schema_uri: &'a SchemaUri,
         definitions: &'a SchemaDefinitions,
         schema_store: &'a SchemaStore,
     ) -> BoxFuture<'b, bool>
@@ -445,18 +470,18 @@ impl ValueSchema {
                         .map(|referable_schema| async {
                             if let Ok(Some(CurrentSchema {
                                 value_schema,
-                                schema_url,
+                                schema_uri,
                                 definitions,
                             })) = referable_schema
                                 .resolve(
-                                    Cow::Borrowed(schema_url),
+                                    Cow::Borrowed(schema_uri),
                                     Cow::Borrowed(definitions),
                                     schema_store,
                                 )
                                 .await
                             {
                                 value_schema
-                                    .is_match(condition, &schema_url, &definitions, schema_store)
+                                    .is_match(condition, &schema_uri, &definitions, schema_store)
                                     .await
                             } else {
                                 false
@@ -474,18 +499,18 @@ impl ValueSchema {
                         .map(|referable_schema| async {
                             if let Ok(Some(CurrentSchema {
                                 value_schema,
-                                schema_url,
+                                schema_uri,
                                 definitions,
                             })) = referable_schema
                                 .resolve(
-                                    Cow::Borrowed(schema_url),
+                                    Cow::Borrowed(schema_uri),
                                     Cow::Borrowed(definitions),
                                     schema_store,
                                 )
                                 .await
                             {
                                 value_schema
-                                    .is_match(condition, &schema_url, &definitions, schema_store)
+                                    .is_match(condition, &schema_uri, &definitions, schema_store)
                                     .await
                             } else {
                                 false
@@ -506,7 +531,7 @@ impl FindSchemaCandidates for ValueSchema {
     fn find_schema_candidates<'a: 'b, 'b>(
         &'a self,
         accessors: &'a [Accessor],
-        schema_url: &'a SchemaUrl,
+        schema_uri: &'a SchemaUri,
         definitions: &'a SchemaDefinitions,
         schema_store: &'a SchemaStore,
     ) -> BoxFuture<'b, (Vec<ValueSchema>, Vec<crate::Error>)> {
@@ -536,7 +561,7 @@ impl FindSchemaCandidates for ValueSchema {
                     for referable_schema in schemas.write().await.iter_mut() {
                         let Ok(Some(current_schema)) = referable_schema
                             .resolve(
-                                Cow::Borrowed(schema_url),
+                                Cow::Borrowed(schema_uri),
                                 Cow::Borrowed(definitions),
                                 schema_store,
                             )
@@ -549,7 +574,7 @@ impl FindSchemaCandidates for ValueSchema {
                             .value_schema
                             .find_schema_candidates(
                                 accessors,
-                                &current_schema.schema_url,
+                                &current_schema.schema_uri,
                                 &current_schema.definitions,
                                 schema_store,
                             )
